from work import check

if __name__ == "main":
    check()
